@@ -118,4 +118,4 @@ class level:
             if save.GetInt(f'{x}_{system}_lvl') > bestlvl:
                 bestlvl = save.GetInt(f'{x}_{system}_lvl')
                 user = x
-        return [user, level]
+        return [user, bestlvl]
